@@ -1,6 +1,9 @@
 # author:	Adrian Rosebrock
 # website:	http://www.pyimagesearch.com
 
+# set the version number
+__version__ = "0.5.2"
+
 # import the necessary packages
 from .convenience import translate
 from .convenience import rotate
@@ -10,7 +13,11 @@ from .convenience import skeletonize
 from .convenience import opencv2matplotlib
 from .convenience import url_to_image
 from .convenience import auto_canny
+from .convenience import grab_contours
 from .convenience import is_cv2
 from .convenience import is_cv3
+from .convenience import is_cv4
 from .convenience import check_opencv_version
+from .convenience import build_montages
+from .convenience import adjust_brightness_contrast
 from .meta import find_function
